@@ -177,7 +177,7 @@ class Unilateral:
         levels. This array is composed of these elements:
 
         +-------------+-------------+-----------------+-------------+
-        | :math:`b_1` | :math:`b_2` | :math:`\\cdots` | :math:`b_n` |
+        | :math:`b_1` | :math:`b_2` | :math:`\\cdots` | :math:`b_n`  |
         +-------------+-------------+-----------------+-------------+
 
         Where :math:`n` is the number of edges between the tumor and the LNLs.
@@ -1006,7 +1006,7 @@ class Unilateral:
         # resulting vector of hidden states to match that involvement of
         # interest
         if isinstance(involvement, dict):
-            involvement = np.array([involvement[lnl.name] for lnl in self.lnls])
+            involvement = np.array([involvement.get(lnl.name, None) for lnl in self.lnls])
         else:
             involvement = np.array(involvement)
 
